@@ -32,7 +32,7 @@ from commit_message_validator.validators.GerritMessageValidator import (
 from commit_message_validator.validators.GitHubMessageValidator import (
     GitHubMessageValidator)
 
-__version__ = '0.6.0'
+__version__ = '0.7.0'
 
 
 WIKIMEDIA_GERRIT_URL = 'gerrit.wikimedia.org'
@@ -134,7 +134,7 @@ def ansi_codes():
     try:
         # Ask git if colors should be used
         # Raises CalledProcessError if disabled
-        subprocess.check_call([
+        subprocess.check_output([
             'git', 'config', '--get-colorbool',
             'color.commit_message_validator', stdout_is_tty
         ])
